Crate mask_tracked_array

Crate mask_tracked_array 

A no std and no alloc abstraction for some data structures on microcontrollers. A MaskTrackedArray is a UnsafeCell<MaybeUninit<T>> with a number mask for tracking which slots are filled and which aren’t. The arrays are allocated at compile time using generics and as such come in different sizes based on the number types.

You can think of a MaskTrackedArray as an array of numbered slots which can be accessed independently (unsafe code may be required).

The current implementations supplied by this crate are

See the documentation on MaskTrackedArray to see what methods are available.

Structs

MaskTrackedArrayBase
An array with slots for values backed by a mask for tracking which slots are under use. Each slot has their own UnsafeCell.
MaskTrackedArrayIter
An iterator for MaskTrackedArray variants.

Traits

Mask
An integer mask trait
MaskTrackedArray
Implemented by every variant of the mask tracked array. The MaskTrackedArray::MaskType is the number type used for the mask.

Type Aliases

MaskTrackedArrayU8
A u8 tracked array which can hold 8 items
MaskTrackedArrayU16
A u16 tracked array which can hold 16 items
MaskTrackedArrayU32
A u32 tracked array which can hold 32 items
MaskTrackedArrayU64
A u64 tracked array which can hold 64 items
MaskTrackedArrayU128
A u128 tracked array which can hold 128 items